﻿using System;
using System.IO;
using System.Windows.Forms;

namespace Sociometry
{
    public partial class KeysForm : Form
    {
        public KeysForm(string firstPolarity, string secondPolarity)
        {
            InitializeComponent();
            dataGridTitle.Columns["FirstPolarityName"].HeaderText = firstPolarity;
            dataGridTitle.Columns["SecondPolarityName"].HeaderText = secondPolarity;
        }

        private void buttonAddKey_Click(object sender, EventArgs e)
        {
            dataGridKeys.Rows.Add();
        }

        private void buttonDeleteKey_Click(object sender, EventArgs e)
        {
            if (dataGridKeys.SelectedCells.Count > 0)
            {
                DialogResult result = MessageBox.Show("Удалить ключ?", "Удаление записи", MessageBoxButtons.YesNo);
                if (result == DialogResult.Yes)
                {
                    dataGridKeys.Rows.Remove(dataGridKeys.CurrentRow);
                }
            }
        }

        private void KeysForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            SaveKeysToFile();
        }

        private void SaveKeysToFile()
        {
            string firstPolarityName = dataGridTitle.Columns["FirstPolarityName"].HeaderText;
            string secondPolarityName = dataGridTitle.Columns["SecondPolarityName"].HeaderText;
            DeleteSection(firstPolarityName, secondPolarityName);
            string header = $"[{firstPolarityName}|{secondPolarityName}]";

            if (dataGridKeys.Rows.Count > 0)
            {
                dataGridKeys.CurrentCell = dataGridKeys.Rows[0].Cells[0];
                for (int i = 0; i < dataGridKeys.RowCount; i++)
                {
                    string value = "";
                    for (int j = 0; j < dataGridKeys.ColumnCount; j++)
                    {
                        if (dataGridKeys.Rows[i].Cells[j].Value != null)
                            value += dataGridKeys.Rows[i].Cells[j].Value.ToString();
                    }
                    if (value.Trim() == "")
                    {
                        dataGridKeys.Rows.RemoveAt(i);
                        i--;
                    }
                }

                string[] values = new string[dataGridKeys.RowCount + 1];
                values[0] = header;
                for (int i = 0; i < dataGridKeys.RowCount; i++)
                {
                    string value = "";
                    for (int j = 0; j < dataGridKeys.ColumnCount; j++)
                    {
                        value += dataGridKeys.Rows[i].Cells[j].Value.ToString() + ";";
                    }

                    values[i + 1] = value.Substring(0, value.Length - 1);
                }
                File.AppendAllLines("keys.txt", values);
            }
        }

        private void DeleteSection(string firstPolarity, string secondPolarity)
        {
            string header = $"[{firstPolarity}|{secondPolarity}]";
            string[] keys = File.ReadAllLines("keys.txt");
            int sectionBegin = Array.IndexOf(keys, header);
            bool sectionExist = sectionBegin > -1;
            if (sectionExist)
            {
                int sectionEnd = keys.Length - 1;
                if (sectionBegin != sectionEnd)
                {
                    for (int i = sectionBegin + 1; i < keys.Length; i++)
                    {
                        if (keys[i].Contains("["))
                        {
                            sectionEnd = i;
                            break;
                        }
                    }
                }

                string[] initialPart = new string[sectionBegin];
                Array.Copy(keys, initialPart, sectionBegin);
                File.WriteAllLines("keys.txt", initialPart);
                if (sectionEnd < keys.Length - 1)
                {
                    string[] finalPart = new string[keys.Length - sectionEnd];
                    Array.Copy(keys, sectionEnd, finalPart, 0, keys.Length - sectionEnd);
                    File.AppendAllLines("keys.txt", finalPart);
                }

            }
        }

        private void KeysForm_Load(object sender, EventArgs e)
        {
            string firstPolarityName = dataGridTitle.Columns["FirstPolarityName"].HeaderText;
            string secondPolarityName = dataGridTitle.Columns["SecondPolarityName"].HeaderText;
            ReadKeysFromFile(firstPolarityName, secondPolarityName);
        }

        private void ReadKeysFromFile(string firstPolarity, string secondPolarity)
        {
            string[] keys = File.ReadAllLines("keys.txt");
            string header = $"[{firstPolarity}|{secondPolarity}]";
            int sectionBegin = Array.IndexOf(keys, header);
            bool sectionExist = (sectionBegin > -1) && (sectionBegin < keys.Length - 1);
            if (sectionExist)
            {
                for (int i = sectionBegin + 1; i < keys.Length; i++)
                {
                    if (keys[i].Contains("["))
                    {
                        break;
                    }
                    else
                    {
                        string value = keys[i];
                        string[] values = value.Split(';');
                        dataGridKeys.Rows.Add(values);
                    }
                }
            }

        }
    }
}
